@@ -8,21 +8,30 @@ Quiq::Url - URL Klasse
 
 =head1 BASE CLASS
 
-L<Quiq::Object>
+L<Quiq::Hash>
+
+=head1 DESCRIPTION
+
+Ein Objekt der Klasse repräsentiert einen URL. Auf dessen Bestandteilen
+kann mit den Objektmethoden der Klasse operiert werden. Ferner enthält
+die Klasse allgemeine Methoden im Zusammenhang mit URLs, die als
+Klassenmethoden implementiert sind.
 
 =cut
 
 # -----------------------------------------------------------------------------
 
 package Quiq::Url;
-use base qw/Quiq::Object/;
+use base qw/Quiq::Hash/;
 
 use v5.10;
 use strict;
 use warnings;
 
-our $VERSION = '1.205';
+our $VERSION = '1.206';
 
+use Quiq::Hash::Ordered;
+use Scalar::Util ();
 use Encode ();
 use Quiq::Array;
 use Quiq::Option;
@@ -37,14 +46,14 @@ use Quiq::Option;
 
 =head4 Synopsis
 
-  $u = $class->new;
+  $urlObj = $class->new;
+  $urlObj = $class->new($url);
+  $urlObj = $class->new(@keyVal);
 
 =head4 Description
 
 Instantiiere ein Objekt der Klasse und liefere eine Referenz auf
-dieses Objekt zurück. Da die Klasse ausschließlich Klassenmethoden
-enthält, hat das Objekt ausschließlich die Funktion, eine abkürzende
-Aufrufschreibweise zu ermöglichen.
+dieses Objekt zurück.
 
 =cut
 
@@ -52,7 +61,180 @@ Aufrufschreibweise zu ermöglichen.
 
 sub new {
     my $class = shift;
-    return bless \(my $dummy),$class;
+    # @_: $url -or- @keyVal
+
+    my ($schema,$user,$password,$host,$port,$path,$fragment) = ('') x 8;
+    if (@_ == 1) {
+        # $url
+
+        my $url = shift;
+        ($schema,$user,$password,$host,$port,$path,my $query,$fragment) =
+            $class->split($url);
+        @_ = map {$class->decode($_)} $class->queryDecode($query);
+    }
+
+    my $self = $class->SUPER::new(
+        schema => $schema,
+        user => $user,
+        password => $password,
+        host => $host,
+        port => $port,
+        path => $path,
+        queryH => Quiq::Hash::Ordered->new,
+        fragment => $fragment,
+    );
+    $self->setQuery(@_);
+
+    return $self;
+}
+
+# -----------------------------------------------------------------------------
+
+=head2 Objektmethoden
+
+=head3 queryString() - liefere Querystring des URL-Objekts
+
+=head4 Synopsis
+
+  $query = $urlObj->queryString;
+
+=head4 Returns
+
+(String) Querystring
+
+=head4 Description
+
+Erzeuge den Querystring des URL-Objekts und liefere diesen zurück.
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub queryString {
+    my $self = shift;
+
+    my $queryH = $self->queryH;
+
+    my @keyVal;
+    for my $key ($queryH->keys) {
+        my $arr = $queryH->get($key);
+        for my $val (@$arr) {
+            push @keyVal,$key=>$val;
+        }
+    }
+
+    return $self->queryEncode(@keyVal);
+}
+
+# -----------------------------------------------------------------------------
+
+=head3 setQuery() - Setze Querystring-Parameter des URL-Objekts
+
+=head4 Synopsis
+
+  $urlObj->setQuery(@keyVal);
+
+=head4 Arguments
+
+=over 4
+
+=item @keyVal
+
+Liste von Schlüssel-Wert-Paaren
+
+=back
+
+=head4 Description
+
+Setze die angegebenen Querystring-Parameter auf den jeweils angegebenen
+Wert. Existiert ein Parameter bereits, wird sein Wert überschrieben.
+Tritt derselbe Parameter mehrfach auf, werden die einzelnen Werte zu
+einem Array zusammengefasst. Ist der Wert eine Arrayreferenz, werden
+alle Werte des Arrays dem Parameter hinzugefügt.
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub setQuery {
+    my $self = shift;
+    # @_ @keyVal
+
+    my $queryH = $self->queryH;
+
+    my %seen;
+    while (@_) {
+        my $key = shift;
+        my $val = shift;
+
+        if (!defined $val) {
+            # undef -> lösche Parameter
+            delete $seen{$key};
+            $queryH->delete($key);
+            next;
+        }
+        elsif (!$seen{$key}++) {
+            # neuen Parameter hinzufügen
+            $queryH->set($key=>[]);
+        }
+
+        # Wert(e) zur Liste der Parameterwerte hinzufügen
+
+        my $arr = $queryH->get($key);
+        my $type = Scalar::Util::reftype($val) // '';
+        push @$arr,$type eq 'ARRAY'? @$val: $val;
+    }
+
+    return;
+}
+
+# -----------------------------------------------------------------------------
+
+=head3 url() - URL als Zeichenkette
+
+=head4 Synopsis
+
+  $url = $urlObj->url;
+
+=head4 Returns
+
+(String) URL als Zeichenkette
+
+=head4 Description
+
+Erzeuge eine externe Repräsentation des URL-Objekts und liefere
+diese zurück.
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub url {
+    my $self = shift;
+
+    my $schema = $self->schema;
+    my $user = $self->user;
+    my $password = $self->password;
+    my $host = $self->host;
+    my $port = $self->port;
+    my $path = $self->path;
+    my $query = $self->queryString;
+    my $fragment = $self->fragment;
+    
+    my $url = $schema;
+    $url .= '://' if $url;
+    $url .= $user;
+    $url .= ":$password" if $password;
+    if ($user && $host) {
+        $url .= '@';
+    }
+    $url .= $host;
+    $url .= ":$port" if $port;
+    $url .= $path;
+    $url .= "?$query" if $query;
+    $url .= "#$fragment" if $fragment;
+
+    return $url;
 }
 
 # -----------------------------------------------------------------------------
@@ -529,7 +711,7 @@ sub split {
 
 =head1 VERSION
 
-1.205
+1.206
 
 =head1 AUTHOR
 
